pub struct LineStringType { /* private fields */ }Expand description
A GeoArrow LineString type.
Refer to the GeoArrow specification.
Implementations
Sourceimpl LineStringType
impl LineStringType
Sourcepub fn new(dim: Dimension, metadata: Arc<Metadata>) -> LineStringType
pub fn new(dim: Dimension, metadata: Arc<Metadata>) -> LineStringType
Construct a new type from parts.
Sourcepub fn with_coord_type(self, coord_type: CoordType) -> LineStringType
pub fn with_coord_type(self, coord_type: CoordType) -> LineStringType
Change the underlying CoordType
Sourcepub fn with_dimension(self, dim: Dimension) -> LineStringType
pub fn with_dimension(self, dim: Dimension) -> LineStringType
Change the underlying Dimension
Sourcepub fn with_metadata(self, metadata: Arc<Metadata>) -> LineStringType
pub fn with_metadata(self, metadata: Arc<Metadata>) -> LineStringType
Change the underlying Metadata
Sourcepub fn coord_type(&self) -> CoordType
pub fn coord_type(&self) -> CoordType
Retrieve the underlying CoordType
Sourceimpl LineStringType
impl LineStringType
Sourcepub fn data_type(&self) -> DataType
pub fn data_type(&self) -> DataType
Convert to the corresponding DataType.
use arrow_schema::{DataType, Field};
use geoarrow_schema::{Dimension, LineStringType};
let geom_type = LineStringType::new(Dimension::XY, Default::default());
let expected_coord_type = DataType::Struct(
vec![
Field::new("x", DataType::Float64, false),
Field::new("y", DataType::Float64, false),
]
.into(),
);
let expected_type = DataType::List(Field::new("vertices", expected_coord_type, false).into());
assert_eq!(geom_type.data_type(), expected_type);Trait Implementations
Sourceimpl Clone for LineStringType
impl Clone for LineStringType
Sourcefn clone(&self) -> LineStringType
fn clone(&self) -> LineStringType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LineStringType
impl Debug for LineStringType
Sourceimpl ExtensionType for LineStringType
impl ExtensionType for LineStringType
Sourceconst NAME: &'static str = "geoarrow.linestring"
const NAME: &'static str = "geoarrow.linestring"
The name identifying this extension type. Read more
Sourcefn metadata(&self) -> &<LineStringType as ExtensionType>::Metadata
fn metadata(&self) -> &<LineStringType as ExtensionType>::Metadata
Returns a reference to the metadata of this extension type, or
&() if
if this extension type defines no metadata (Self::Metadata=()).Sourcefn serialize_metadata(&self) -> Option<String>
fn serialize_metadata(&self) -> Option<String>
Returns the serialized representation of the metadata of this extension
type, or
None if this extension type defines no metadata
(Self::Metadata=()). Read moreSourcefn deserialize_metadata(
metadata: Option<&str>,
) -> Result<<LineStringType as ExtensionType>::Metadata, ArrowError>
fn deserialize_metadata( metadata: Option<&str>, ) -> Result<<LineStringType as ExtensionType>::Metadata, ArrowError>
Deserialize the metadata of this extension type from the serialized
representation of the metadata. An extension type that defines no
metadata should expect
None for the serialized metadata and return
Ok(()). Read moreSourcefn supports_data_type(&self, data_type: &DataType) -> Result<(), ArrowError>
fn supports_data_type(&self, data_type: &DataType) -> Result<(), ArrowError>
Returns
Ok(()) iff the given data type is supported by this extension
type.Sourcefn try_new(
data_type: &DataType,
metadata: <LineStringType as ExtensionType>::Metadata,
) -> Result<LineStringType, ArrowError>
fn try_new( data_type: &DataType, metadata: <LineStringType as ExtensionType>::Metadata, ) -> Result<LineStringType, ArrowError>
Construct this extension type for a field with the given data type and
metadata. Read more
Sourceimpl From<LineStringType> for GeoArrowType
impl From<LineStringType> for GeoArrowType
Sourcefn from(value: LineStringType) -> GeoArrowType
fn from(value: LineStringType) -> GeoArrowType
Converts to this type from the input type.
Sourceimpl GeometryTypeId for LineStringType
impl GeometryTypeId for LineStringType
Sourceimpl Hash for LineStringType
impl Hash for LineStringType
Sourceimpl PartialEq for LineStringType
impl PartialEq for LineStringType
Sourceimpl WrapArray<&GenericListArray<i32>> for LineStringType
impl WrapArray<&GenericListArray<i32>> for LineStringType
Sourcetype Output = LineStringArray
type Output = LineStringArray
The output GeoArrow array type.
Sourcefn wrap_array(
&self,
input: &GenericListArray<i32>,
) -> Result<<LineStringType as WrapArray<&GenericListArray<i32>>>::Output, GeoArrowError>
fn wrap_array( &self, input: &GenericListArray<i32>, ) -> Result<<LineStringType as WrapArray<&GenericListArray<i32>>>::Output, GeoArrowError>
Wrap the given storage array as an GeoArrow array. Read more
Sourceimpl WrapArray<&dyn Array> for LineStringType
impl WrapArray<&dyn Array> for LineStringType
Sourcetype Output = LineStringArray
type Output = LineStringArray
The output GeoArrow array type.
Sourcefn wrap_array(
&self,
input: &dyn Array,
) -> Result<<LineStringType as WrapArray<&dyn Array>>::Output, GeoArrowError>
fn wrap_array( &self, input: &dyn Array, ) -> Result<<LineStringType as WrapArray<&dyn Array>>::Output, GeoArrowError>
Wrap the given storage array as an GeoArrow array. Read more
impl Eq for LineStringType
impl StructuralPartialEq for LineStringType